"""Initial tables.

Revision ID: 63139caea00e
Revises: 
Create Date: 2024-03-14 09:40:20.864282

"""
from collections.abc import Sequence

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision: str = "63139caea00e"
down_revision: str | None = None
branch_labels: str | Sequence[str] | None = None
depends_on: str | Sequence[str] | None = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "email_subscriber",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("email", sa.String(), nullable=True),
        sa.Column("created_at", sa.DateTime(timezone=True), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("email_subscriber_pkey")),
        sa.UniqueConstraint("email", name=op.f("email_subscriber_email_key")),
    )
    op.create_table(
        "series",
        sa.Column("name", sa.String(), nullable=False),
        sa.Column("url", sa.Text(), nullable=False),
        sa.Column("type", sa.String(), nullable=False),
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("title", sa.String(), nullable=False),
        sa.Column("author", sa.String(), nullable=True),
        sa.Column("cover_url", sa.Text(), nullable=True),
        sa.Column("settings", sa.JSON(none_as_null=True), nullable=True),
        sa.Column("last_built_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column("created_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column("ebook", sa.LargeBinary(), nullable=True),
        sa.PrimaryKeyConstraint("id", name=op.f("series_pkey")),
        sa.UniqueConstraint("name", name=op.f("series_name_key")),
    )
    op.create_table(
        "chapter",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("series_id", sa.Integer(), nullable=False),
        sa.Column("title", sa.String(), nullable=False),
        sa.Column("url", sa.Text(), nullable=False),
        sa.Column("number", sa.Integer(), nullable=False),
        sa.Column("content", sa.Text(), nullable=False),
        sa.Column("ebook", sa.LargeBinary(), nullable=True),
        sa.Column("sent_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column("published_at", sa.DateTime(timezone=True), nullable=False),
        sa.Column("created_at", sa.DateTime(timezone=True), nullable=False),
        sa.ForeignKeyConstraint(
            ["series_id"], ["series.id"], name=op.f("chapter_series_id_fkey")
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("chapter_pkey")),
        sa.UniqueConstraint(
            "series_id", "number", name=op.f("chapter_series_id_number_key")
        ),
    )
    op.create_table(
        "email_subscription",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("series_id", sa.Integer(), nullable=False),
        sa.Column("subscriber_id", sa.Integer(), nullable=False),
        sa.Column("created_at", sa.DateTime(timezone=True), nullable=False),
        sa.ForeignKeyConstraint(
            ["series_id"], ["series.id"], name=op.f("email_subscription_series_id_fkey")
        ),
        sa.ForeignKeyConstraint(
            ["subscriber_id"],
            ["email_subscriber.id"],
            name=op.f("email_subscription_subscriber_id_fkey"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("email_subscription_pkey")),
        sa.UniqueConstraint(
            "series_id",
            "subscriber_id",
            name=op.f("email_subscription_series_id_subscriber_id_key"),
        ),
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("email_subscription")
    op.drop_table("chapter")
    op.drop_table("series")
    op.drop_table("email_subscriber")
    # ### end Alembic commands ###
